@@ -4,6 +4,7 @@
 __author__ = "lzz"
 '''
 参考：
+https://github.com/openatx/uiautomator2
 https://github.com/gb112211/Adb-For-Test
 项目地址：https://github.com/lizonezhi/uitest
 支持python3.6
@@ -16,6 +17,7 @@ import platform
 import subprocess
 import re
 import time
+import datetime
 
 import xml.etree.cElementTree as ET
 
@@ -357,11 +359,54 @@ def __time_jishi(lineTmpla, udid_all, device, recovery, sideload, fastboot, time
             if time.time() - start_time > timeout:
                 print_color('超时%s秒，自动退出' % (timeout), 4)
                 break
-
+def get_local_ip(LAN=False):
+    '''
+        获取电脑本地ip地址
+        LAN = True 时表示获取192.168开头的局域网ip
+    '''
+    import psutil
+    ip = ''
+    try:
+        for k, v, in psutil.net_if_addrs().items():
+            if "无线" in k or "WLAN" in k or "以太" in k:
+                for item in v:
+                    ip_tmp = item[1]
+                    try:
+                        if LAN:
+                            ip = re.search('(192)\.(168)\.([\d]{1,3}\.){1}[\d]{1,3}', ip_tmp).group()
+                        else:
+                            ip = re.search('([\d]{1,3}\.){3}[\d]{1,3}', ip_tmp).group()
+                        if ip:
+                            break
+                    except:
+                        pass
+    except Exception as e:
+        print('Exception:' + e.args)
+    return ip
+def print_log(content='content', path='log/'):
+    '''
+    写入内容到电脑本地txt文件，指定路径
+    :param name:文件名  content：内容
+    :return: True or False 写入成功或失败
+    ：usage： write_txt_file(name='记录日志', content='123')
+    '''
+    try:
+        # 获取今天的字符串
+        time_ymd = time.strftime("%Y-%m-%d", time.localtime(time.time()))
+        time_ymdhms = time.strftime("%Y-%m-%d %H:%M:%S", time.localtime(time.time()))
+        msg = time_ymdhms + "  ：" + content + '\n'
+        if not os.path.isdir(path):
+            os.makedirs(path, exist_ok=True)
+        f = open(path + '%s.log' % (time_ymd), 'a')
+        f.write('%s \n' % (msg))
+        f.close()
+        return True
+    except:
+        return False
 def write_txt_file(name='name', content='content'):
     '''
     写入内容到电脑本地txt文件
-    :param name:文件名  content：内容 
+    :param name:文件名  content：内容
     :return: True or False 写入成功或失败
     ：usage： write_txt_file(name='记录日志', content='123')
     '''
@@ -375,7 +420,7 @@ def write_txt_file(name='name', content='content'):
 def read_txt_file(name='name'):
     '''
     写入文件到电脑本地
-    :param name:文件名  content：内容 
+    :param name:文件名  content：内容
     :return: True or False 写入成功或失败
     ：usage： write_txt_file(name='记录日志', content='123')
     '''
@@ -1522,22 +1567,38 @@ class Device(object):
         """
         获取当前应用界面的包名和Activity，返回的字符串格式为：packageName/activityName
         """
-        pattern = re.compile(r"[a-zA-Z0-9\.]+/.[a-zA-Z0-9\.]+")
-        out = self.shell("dumpsys window w | %s \/ | %s name=" % (find_util, find_util)).stdout.read()
+        # pattern = re.compile(r"[a-zA-Z0-9\.]+/.[a-zA-Z0-9\.]+")
+        # out = self.shell("dumpsys window w | %s \/ | %s name=" % (find_util, find_util)).stdout.read()
+        # 
+        # return pattern.findall(out.decode('utf8'))[0]
 
-        return pattern.findall(out.decode('utf8'))[0]
+        packageName = subprocess.check_output(
+            'adb -s %s shell dumpsys activity top | grep ACTIVITY' % (getUdid())).decode()
+        packageName_list = packageName.split('ACTIVITY')
+        packageName = packageName_list[-1]
+        
+        packageName = packageName.strip()
+        packageName = ' '.join(packageName.split(' ')[:1])
+        return packageName
 
     def getCurrentPackageName(self):
         """
         获取当前运行的应用的包名
         """
-        return self.getFocusedPackageAndActivity().split("/")[0]
+        # return self.getFocusedPackageAndActivity().split("/")[0]
+
+        
+        packageName = '/'.join(self.getFocusedPackageAndActivity().split('/')[:1])
+        return packageName
 
     def getCurrentActivity(self):
         """
         获取当前运行应用的activity
         """
-        return self.getFocusedPackageAndActivity().split("/")[-1]
+        # return self.getFocusedPackageAndActivity().split("/")[-1]
+
+        packageName = self.getFocusedPackageAndActivity().split('/')[1]
+        return packageName
     def getMemTotal(self):
         """
         获取最大内存
@@ -1695,6 +1756,16 @@ class Device(object):
 
         return thirdApp
 
+    def getInstalledAppList(self):
+        """
+        获取设备中所有安装的应用包名列表
+        """
+        thirdApp = []
+        for packages in self.shell("pm list packages").stdout.readlines():
+            thirdApp.append(packages.decode('utf8').split(":")[-1].splitlines()[0])
+
+        return thirdApp
+
     def getMatchingAppList(self, keyword):
         """
         模糊查询与keyword匹配的应用包名列表
@@ -1729,7 +1800,13 @@ class Device(object):
         根据包名判断应用是否安装，已安装返回True，否则返回False
         usage: isInstall("com.example.apidemo")
         """
-        if self.getMatchingAppList(packageName):
+        matApp = []
+        for packages in self.shell("pm list packages %s" % packageName).stdout.readlines():
+            package = packages.decode('utf8').split(":")[-1].splitlines()[0]
+            if package == packageName:
+                matApp.append(package)
+                break
+        if matApp:
             return True
         else:
             return False
@@ -2004,9 +2081,9 @@ class Device(object):
     # 点亮解锁屏幕
     def screen_on(self):
         self.sendKeyEvent(keycode=224)
-        if Element().info(resourceId='com.android.systemui:id/lock_icon'):
-            self.sendKeyEvent(keycode=224)
-            self.swipeToUp()
+        # if Element().info(resourceId='com.android.systemui:id/lock_icon'):
+        #     self.sendKeyEvent(keycode=224)
+        #     self.swipeToUp()
     # 熄灭屏幕
     def screen_off(self):
         self.sendKeyEvent(keycode=223)
@@ -2072,6 +2149,8 @@ class Device(object):
         :return: 0内部版本号、1版本名、2首次安装时间、3上次安装时间、4data/app/路径、5是否拆分
         '''
         if packageName != '':
+            if not self.isInstall(packageName):
+                return []
             versionName = self.shell_return(
                 'dumpsys package %s | grep versionName' % (packageName)).replace(
                 '\n', '').replace('\r', '').strip()
@@ -2108,6 +2187,8 @@ class Device(object):
                 splits = True
             resourcePath = resourcePath.replace('resourcePath=','')
             return [versionName, versionCode, versionFirstTime, versionTime, resourcePath, splits]
+        else:
+            return []
     # 获取sn号
     def get_sn(self):
         serialno = self.shell_return('getprop persist.sys.product.serialno').replace(
@@ -2219,6 +2300,33 @@ class Device(object):
         print('接收数据package_rx_bytes:', package_rx_bytes, '传输数据package_tx_bytes:', package_tx_bytes)
         return [package_rx_bytes, package_tx_bytes, round(package_rx_bytes/1024), round(package_tx_bytes/1024), round((package_rx_bytes+package_tx_bytes)/1024/1024)]
 
+    # 判断设备是否root
+    def is_root(self):
+        if 'cannot' in self.adb_return('root'):
+            return False
+        else:
+            return True
+
+    # 获取设备开机时间
+    def get_boot_time(self):
+        s_1970 = self.shell_return('cat proc/stat | grep btime')# 1970秒数
+        s_1970 = s_1970.replace('btime ', '').replace('\r', '').replace('\n', '')
+        timeArray = time.localtime(int(s_1970))
+        us_time = time.strftime("%Y-%m-%d %H:%M:%S", timeArray)
+        return datetime.datetime.strptime(us_time, "%Y-%m-%d %H:%M:%S")
+
+    # 获取设备已开机时间
+    def get_has_boot_time(self, show='s'):
+        s_1970 = self.shell_return('cat proc/stat | grep btime')  # 1970秒数
+        s_1970 = s_1970.replace('btime ', '').replace('\r', '').replace('\n', '')
+        time_s = time.time() - float(s_1970)
+        if show == 's':
+            return round(time_s, 3)
+        elif show == 'm':
+            return round(time_s / 60, 2)
+        elif show == 'h':
+            return round(time_s / 60 / 60, 1)
+
 import json
 # 支持自动序列化的基类
 class archive_json(object):
